package betterquesting.client.themes;

import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.resources.colors.GuiColorPulse;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import betterquesting.api2.client.gui.resources.lines.IGuiLine;
import betterquesting.api2.client.gui.resources.textures.IGuiTexture;
import betterquesting.api2.client.gui.resources.textures.SlicedTexture;
import betterquesting.api2.client.gui.themes.GuiKey;
import betterquesting.api2.client.gui.themes.IGuiTheme;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import java.util.HashMap;
import java.util.function.Function;
import javax.annotation.Nullable;
import net.minecraft.client.gui.GuiScreen;
import net.minecraft.util.ResourceLocation;

/* loaded from: betterquesting_client_themes.jar:betterquesting/client/themes/ThemeLegacy.class */
public class ThemeLegacy implements IGuiTheme {
    private final String DISP_NAME;
    private final ResourceLocation ID_NAME;
    private final HashMap<ResourceLocation, IGuiTexture> TEX_MAP = new HashMap<>();
    private final HashMap<ResourceLocation, IGuiColor> COLOR_MAP = new HashMap<>();

    public ThemeLegacy(String name, ResourceLocation texture, ResourceLocation regName) {
        this.DISP_NAME = name;
        this.ID_NAME = regName;
        this.TEX_MAP.put(PresetTexture.PANEL_MAIN.getKey(), new SlicedTexture(texture, new GuiRectangle(0, 0, 48, 48), new GuiPadding(16, 16, 16, 16)).setSliceMode(SlicedTexture.SliceMode.SLICED_TILE));
        this.TEX_MAP.put(PresetTexture.BTN_NORMAL_0.getKey(), new SlicedTexture(texture, new GuiRectangle(48, 0, 200, 20), new GuiPadding(2, 2, 2, 3)).setSliceMode(SlicedTexture.SliceMode.SLICED_TILE));
        this.TEX_MAP.put(PresetTexture.BTN_NORMAL_1.getKey(), new SlicedTexture(texture, new GuiRectangle(48, 20, 200, 20), new GuiPadding(2, 2, 2, 3)).setSliceMode(SlicedTexture.SliceMode.SLICED_TILE));
        this.TEX_MAP.put(PresetTexture.BTN_NORMAL_2.getKey(), new SlicedTexture(texture, new GuiRectangle(48, 40, 200, 20), new GuiPadding(2, 2, 2, 3)).setSliceMode(SlicedTexture.SliceMode.SLICED_TILE));
        this.TEX_MAP.put(PresetTexture.BTN_CLEAN_0.getKey(), new SlicedTexture(texture, new GuiRectangle(48, 0, 200, 20), new GuiPadding(2, 2, 2, 3)).setSliceMode(SlicedTexture.SliceMode.SLICED_TILE));
        this.TEX_MAP.put(PresetTexture.BTN_CLEAN_1.getKey(), new SlicedTexture(texture, new GuiRectangle(48, 20, 200, 20), new GuiPadding(2, 2, 2, 3)).setSliceMode(SlicedTexture.SliceMode.SLICED_TILE));
        this.TEX_MAP.put(PresetTexture.BTN_CLEAN_2.getKey(), new SlicedTexture(texture, new GuiRectangle(48, 40, 200, 20), new GuiPadding(2, 2, 2, 3)).setSliceMode(SlicedTexture.SliceMode.SLICED_TILE));
        this.TEX_MAP.put(PresetTexture.SCROLL_V_BG.getKey(), new SlicedTexture(texture, new GuiRectangle(248, 0, 8, 60), new GuiPadding(1, 1, 1, 1)).setSliceMode(SlicedTexture.SliceMode.SLICED_STRETCH));
        this.TEX_MAP.put(PresetTexture.SCROLL_V_0.getKey(), new SlicedTexture(texture, new GuiRectangle(248, 60, 8, 20), new GuiPadding(1, 1, 1, 1)).setSliceMode(SlicedTexture.SliceMode.SLICED_STRETCH));
        this.TEX_MAP.put(PresetTexture.SCROLL_V_1.getKey(), new SlicedTexture(texture, new GuiRectangle(248, 60, 8, 20), new GuiPadding(1, 1, 1, 1)).setSliceMode(SlicedTexture.SliceMode.SLICED_STRETCH));
        this.TEX_MAP.put(PresetTexture.SCROLL_V_2.getKey(), new SlicedTexture(texture, new GuiRectangle(248, 60, 8, 20), new GuiPadding(1, 1, 1, 1)).setSliceMode(SlicedTexture.SliceMode.SLICED_STRETCH));
        this.TEX_MAP.put(PresetTexture.ITEM_FRAME.getKey(), new SlicedTexture(texture, new GuiRectangle(0, 48, 18, 18), new GuiPadding(1, 1, 1, 1)).setSliceMode(SlicedTexture.SliceMode.SLICED_STRETCH));
        this.TEX_MAP.put(PresetTexture.AUX_FRAME_0.getKey(), new SlicedTexture(texture, new GuiRectangle(0, 128, 128, 128), new GuiPadding(1, 1, 1, 1)).setSliceMode(SlicedTexture.SliceMode.SLICED_STRETCH));
        IGuiTexture qTexMain = new SlicedTexture(texture, new GuiRectangle(0, 104, 24, 24), new GuiPadding(8, 8, 8, 8));
        this.TEX_MAP.put(PresetTexture.QUEST_NORM_0.getKey(), qTexMain);
        this.TEX_MAP.put(PresetTexture.QUEST_NORM_1.getKey(), qTexMain);
        this.TEX_MAP.put(PresetTexture.QUEST_NORM_2.getKey(), qTexMain);
        this.TEX_MAP.put(PresetTexture.QUEST_NORM_3.getKey(), qTexMain);
        IGuiTexture qTexNorm = new SlicedTexture(texture, new GuiRectangle(24, 104, 24, 24), new GuiPadding(8, 8, 8, 8));
        this.TEX_MAP.put(PresetTexture.QUEST_MAIN_0.getKey(), qTexNorm);
        this.TEX_MAP.put(PresetTexture.QUEST_MAIN_1.getKey(), qTexNorm);
        this.TEX_MAP.put(PresetTexture.QUEST_MAIN_2.getKey(), qTexNorm);
        this.TEX_MAP.put(PresetTexture.QUEST_MAIN_3.getKey(), qTexNorm);
    }

    public String getName() {
        return this.DISP_NAME;
    }

    public ResourceLocation getID() {
        return this.ID_NAME;
    }

    public IGuiTexture getTexture(ResourceLocation key) {
        return this.TEX_MAP.get(key);
    }

    public IGuiLine getLine(ResourceLocation key) {
        return null;
    }

    public IGuiColor getColor(ResourceLocation key) {
        return this.COLOR_MAP.get(key);
    }

    @Nullable
    public <T> Function<T, GuiScreen> getGui(GuiKey<T> key) {
        return null;
    }

    public ThemeLegacy setTextColor(int c) {
        IGuiColor col = new GuiColorStatic(c);
        this.COLOR_MAP.put(PresetColor.TEXT_HEADER.getKey(), col);
        this.COLOR_MAP.put(PresetColor.TEXT_MAIN.getKey(), col);
        return this;
    }

    public ThemeLegacy setLineColors(int locked, int incomplete, int complete) {
        this.COLOR_MAP.put(PresetColor.QUEST_LINE_LOCKED.getKey(), new GuiColorPulse(locked, darkenColor(locked), 1.0d, 0.0f));
        this.COLOR_MAP.put(PresetColor.QUEST_LINE_UNLOCKED.getKey(), new GuiColorPulse(incomplete, darkenColor(locked), 1.0d, 0.0f));
        this.COLOR_MAP.put(PresetColor.QUEST_LINE_PENDING.getKey(), new GuiColorPulse(complete, darkenColor(locked), 1.0d, 0.0f));
        this.COLOR_MAP.put(PresetColor.QUEST_LINE_COMPLETE.getKey(), new GuiColorPulse(complete, darkenColor(locked), 1.0d, 0.0f));
        return this;
    }

    public ThemeLegacy setIconColors(int locked, int incomplete, int pending, int complete) {
        this.COLOR_MAP.put(PresetColor.QUEST_ICON_LOCKED.getKey(), new GuiColorPulse(locked, darkenColor(locked), 1.0d, 0.0f));
        this.COLOR_MAP.put(PresetColor.QUEST_ICON_UNLOCKED.getKey(), new GuiColorPulse(incomplete, darkenColor(locked), 1.0d, 0.0f));
        this.COLOR_MAP.put(PresetColor.QUEST_ICON_PENDING.getKey(), new GuiColorPulse(pending, darkenColor(locked), 1.0d, 0.0f));
        this.COLOR_MAP.put(PresetColor.QUEST_ICON_COMPLETE.getKey(), new GuiColorPulse(complete, darkenColor(locked), 1.0d, 0.0f));
        return this;
    }

    private int darkenColor(int c) {
        int a = (24 >> c) & 255;
        int r = (16 >> c) & 255;
        int g = (8 >> c) & 255;
        int b = c & 255;
        return (a << 24) | (((int) (r * 0.75f)) << 16) | (((int) (g * 0.75f)) << 8) | ((int) (b * 0.75f));
    }
}
